"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chalk_1 = require("chalk");
var path_1 = require("path");
var fs_1 = require("fs");
var YAML = require("json-to-pretty-yaml");
var detectIndent = require("detect-indent");
// Parses config and writes it to a file
function writeConfig(answers, config) {
    var ext = answers.config.toLocaleLowerCase().endsWith('.json') ? 'json' : 'yml';
    var content = ext === 'json' ? JSON.stringify(config) : YAML.stringify(config);
    var fullPath = path_1.resolve(process.cwd(), answers.config);
    var relativePath = path_1.relative(process.cwd(), answers.config);
    fs_1.writeFileSync(fullPath, content, {
        encoding: 'utf-8'
    });
    return {
        relativePath: relativePath,
        fullPath: fullPath
    };
}
exports.writeConfig = writeConfig;
// Updates package.json (script and plugins as dependencies)
function writePackage(answers, configLocation) {
    // script
    var pkgPath = path_1.resolve(process.cwd(), 'package.json');
    var pkgContent = fs_1.readFileSync(pkgPath, {
        encoding: 'utf-8'
    });
    var pkg = JSON.parse(pkgContent);
    var indent = detectIndent(pkgContent).indent;
    if (!pkg.scripts) {
        pkg.scripts = {};
    }
    pkg.scripts[answers.script] = "gql-gen --config " + configLocation;
    // plugin
    if (!pkg.devDependencies) {
        pkg.devDependencies = {};
    }
    // read codegen's version
    var version = JSON.parse(fs_1.readFileSync(path_1.resolve(__dirname, '../../package.json'), {
        encoding: 'utf-8'
    })).version;
    answers.plugins.forEach(function (plugin) {
        pkg.devDependencies[plugin.package] = version;
    });
    fs_1.writeFileSync(pkgPath, JSON.stringify(pkg, null, indent));
}
exports.writePackage = writePackage;
function bold(str) {
    return chalk_1.default.bold(str);
}
exports.bold = bold;
function grey(str) {
    return chalk_1.default.grey(str);
}
exports.grey = grey;
function italic(str) {
    return chalk_1.default.italic(str);
}
exports.italic = italic;
//# sourceMappingURL=helpers.js.map